@@ -1,5 +1,9 @@
 #!/usr/bin/env python3
 
+"""
+Logs browser implementation.
+"""
+
 from collections import namedtuple
 
 import keyboard
@@ -9,13 +13,17 @@ from foodlog import logs_viewer
 
 
 class LogsBrowser:
+    """
+    Class for a logs browser.
+    """
+
     _data: namedtuple
 
     _max_index: int = 0
     _index: int = 0
 
-    _prev_log_hotkey: str = "Left"
-    _next_log_hotkey: str = "Right"
+    _prev_log_hotkey: str = "A"
+    _next_log_hotkey: str = "D"
     _exit_hotkey: str = "Esc"
 
     def __init__(self, data: namedtuple):
@@ -25,17 +33,23 @@ class LogsBrowser:
         self._index = self._max_index
 
     def open(self) -> None:
+        """
+        Opens journal browser.
+        """
 
         self.show_log_by_index()
 
-        keyboard.add_hotkey(self._prev_log_hotkey, self.show_previous_fast)
-        keyboard.add_hotkey(self._next_log_hotkey, self.show_next_fast)
+        keyboard.add_hotkey(self._prev_log_hotkey, self.show_previous_day)
+        keyboard.add_hotkey(self._next_log_hotkey, self.show_next_day)
 
         keyboard.wait(self._exit_hotkey)
 
         keyboard.remove_all_hotkeys()
 
     def show_log_by_index(self):
+        """
+        Prints summary by an index given.
+        """
 
         cliutils.clear_terminal()
 
@@ -51,12 +65,20 @@ class LogsBrowser:
         )
         print(f"Press [{self._exit_hotkey}] to return to the main menu.")
 
-    def show_previous_fast(self):
+    def show_previous_day(self):
+        """
+        Prints summary for a previous day.
+        """
+
         if self._index > 0:
             self._index -= 1
             self.show_log_by_index()
 
-    def show_next_fast(self):
+    def show_next_day(self):
+        """
+        Prints summary for a next day.
+        """
+
         if self._index < self._max_index:
             self._index += 1
             self.show_log_by_index()
